@@ -99,6 +99,7 @@ static void tui_tab_item_draw_node(const struct tui_tab_item *const item,
 
     DRAW(DESCRIPTION) {
         wchar_t line[usable_width];
+        wchar_t *lineptr = line;
 
         const char *name_str = "NULL";
         if (node->node_description != NULL) {
@@ -107,19 +108,18 @@ static void tui_tab_item_draw_node(const struct tui_tab_item *const item,
             name_str = node->node_name;
         }
 
-        if (config.display_ids) {
-            swprintf(line, SIZEOF_ARRAY(line), L"(%d) %s%s%s%-*s",
-                     node->id, name_str,
-                     (node->media_name == NULL) ? "" : ": ",
-                     (node->media_name == NULL) ? "" : node->media_name,
-                     usable_width, "");
-        } else {
-            swprintf(line, SIZEOF_ARRAY(line), L"%s%s%s%-*s",
-                     name_str,
-                     (node->media_name == NULL) ? "" : ": ",
-                     (node->media_name == NULL) ? "" : node->media_name,
-                     usable_width, "");
+        if (node->is_default) {
+            lineptr += swprintf(lineptr, usable_width - (lineptr - line), L"[*] ");
         }
+        if (config.display_ids) {
+            lineptr += swprintf(lineptr, usable_width - (lineptr - line), L"%d. ", node->id);
+        }
+        swprintf(lineptr, usable_width - (lineptr - line), L"%s%s%s%-*s",
+                 name_str,
+                 (node->media_name == NULL) ? "" : ": ",
+                 (node->media_name == NULL) ? "" : node->media_name,
+                 usable_width, "");
+
         wcstrimcols(line, usable_width);
         mvwaddnwstr(win, item->pos + 1, info_area_start, line, usable_width);
     }
@@ -330,7 +330,13 @@ static void tui_tab_item_draw_device(const struct tui_tab_item *const item,
 
     DRAW(DESCRIPTION) {
         wchar_t line[usable_width];
-        swprintf(line, SIZEOF_ARRAY(line), L"%d. %s", dev->id, dev->description);
+        wchar_t *lineptr = line;
+
+        if (config.display_ids) {
+            lineptr += swprintf(lineptr, usable_width - (lineptr - line), L"%d. ", dev->id);
+        }
+        swprintf(lineptr, usable_width - (lineptr - line), L"%s", dev->description);
+
         mvwaddnwstr(win, item->pos + 1, 1, line, SIZEOF_ARRAY(line));
         wclrtoeol(win);
     }
@@ -787,6 +793,17 @@ void tui_bind_set_tab_index(union tui_bind_data data) {
     tui_set_tab_and_redraw(index);
 }
 
+void tui_bind_set_default(union tui_bind_data data) {
+    struct tui_tab_item *const focused = tui.tabs[tui.tab_index].focused;
+
+    if (focused == NULL || focused->type != TUI_TAB_ITEM_TYPE_NODE || tui.menu_active) {
+        return;
+    }
+
+    const struct node *const node = node_lookup(focused->as.node.node_id);
+    node_set_default(node);
+}
+
 static void on_profile_selection_done(struct tui_menu *menu, struct tui_menu_item *pick) {
     const uint32_t device_id = menu->data.uint;
     const uint32_t profile_id = pick->data.uint;
@@ -916,6 +933,18 @@ void tui_bind_confirm_selection(union tui_bind_data data) {
     menu->callback(menu, &menu->items[menu->selected]);
 }
 
+void tui_bind_quit_or_cancel_selection(union tui_bind_data data) {
+    if (tui.menu_active) {
+        tui_bind_cancel_selection(data);
+    } else {
+        tui_bind_quit(data);
+    }
+}
+
+void tui_bind_quit(union tui_bind_data data) {
+    pollen_loop_quit(event_loop, 0);
+}
+
 static WINDOW *tui_resize_pad(WINDOW *pad, int y, int x, bool keep_contents) {
     TRACE("tui_resize_pad: y %d x %d", y, x);
 
@@ -1086,6 +1115,10 @@ static void on_node_events(uint64_t events,
         }
         break;
     }
+    case NODE_EVENT_DEFAULT: {
+        tui_tab_item_draw(item, TUI_TAB_ITEM_DRAW_DESCRIPTION);
+        break;
+    }
     case NODE_EVENT_REMOVE: {
         on_node_remove(item);
         break;
@@ -1267,8 +1300,6 @@ static int on_stdin_ready(struct pollen_event_source *_, int _, uint32_t _, void
         struct tui_bind *bind = MAP_GET(&config.binds, ch);
         if (bind == NULL) {
             DEBUG("unhandled key %s (%d)", key_name_from_key_code(ch), ch);
-        } else if (bind->func == TUI_BIND_QUIT) {
-            pollen_loop_quit(event_loop, 0);
         } else {
             bind->func(bind->data);
             trigger_update();
