@@ -20,3 +20,6 @@ size_t wcstrimcols(wchar_t *str, size_t col);
 
 char *read_string_from_fd(int fd, size_t *len);
 
+/* compares two strings, safely handles NULL (NULL is distinct from NULL) */
+bool streq(const char *a, const char *b);
+
